@@ -1,6 +1,6 @@
 package Net::Google::Analytics::Request;
 {
-  $Net::Google::Analytics::Request::VERSION = '3.00';
+  $Net::Google::Analytics::Request::VERSION = '3.01';
 }
 use strict;
 
@@ -70,7 +70,7 @@ Net::Google::Analytics::Request - Google Analytics API request
 
 =head1 VERSION
 
-version 3.00
+version 3.01
 
 =head1 SYNOPSIS
 
@@ -103,14 +103,30 @@ shorthand L<Net::Google::Analytics/new_request>.
 
 =head1 ACCESSORS
 
+    $req->ids('ga:...');
+    $req->dimensions('ga:...');
+
+See the
+L<API reference|http://code.google.com/apis/analytics/docs/gdata/v3/reference.html#data_request>
+for a description of the request parameters. The provided parameter values must
+not be URL encoded.
+
 =head2 ids
 
+Required
+
 =head2 start_date
 
+Required
+
 =head2 end_date
 
+Required
+
 =head2 metrics
 
+Required
+
 =head2 dimensions
 
 =head2 sort
@@ -131,12 +147,6 @@ shorthand L<Net::Google::Analytics/new_request>.
 
 =head2 quota_user
 
- $req->ids('ga:...');
- $req->dimensions('ga:...');
-
-See the API reference for a description of the request parameters. The
-provided parameter values must not be URL encoded.
-
 =head1 AUTHOR
 
 Nick Wellnhofer <wellnhofer@aevum.de>
